<?php

class Rankings {

	function GetResults($limit=10,$order=null,$direction="DESC",$select="*",$table=_TBL_CHR_,$group=null,$usedb2=false) {
		global $dB,$dB2;
		if(Validator::Number($limit)) {
			$build_query = "SELECT TOP $limit $select FROM $table ";
			if(check_value($group)) {
				$build_query .= "GROUP BY $group ";
			}
			if(check_value($order)) {
				$build_query .= "ORDER BY $order $direction";
			}
			if(config('SQL_USE_2_DB',true)) {
				if($usedb2) {
					$result = $dB2->query_fetch($build_query);
				} else {
					$result = $dB->query_fetch($build_query);
				}
			} else {
				$result = $dB->query_fetch($build_query);
			}
			if(is_array($result)) {
				return $result;
			} else {
				return null;
			}
		} else {
			return null;
		}
	}
	
	function UpdateRankingCache($ranking_type) {
		global $config, $dB;
		loadModuleConfigs('rankings');
		switch($ranking_type) {
			case 'level':
				$dbDATA = $this->GetResults(mconfig('rankings_results'),'cLevel','DESC','Name,Class,cLevel');
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_level.cache',$cacheDATA);
			break;
			case 'resets':
				$dbDATA = $this->GetResults(mconfig('rankings_results'),'Resets','DESC','Name,Class,Resets');
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_resets.cache',$cacheDATA);
			break;
			case 'killers':
				$dbDATA = $this->GetResults(mconfig('rankings_results'),'CirePkRank','DESC','Name,Class,CirePkRank');
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_pk.cache',$cacheDATA);
			break;
			case 'grandresets':
				//$dbDATA = $this->GetResults(mconfig('rankings_results'),'Grand_Resets','DESC','Name,Class,Grand_Resets,Resets');
				$dbDATA = $dB->query_fetch("SELECT TOP ".mconfig('rankings_results')." "._CLMN_CHR_NAME_.", "._CLMN_CHR_GRSTS_.", "._CLMN_CHR_RSTS_.", "._CLMN_CHR_CLASS_." FROM "._TBL_CHR_." WHERE "._CLMN_CHR_GRSTS_." >= 1 ORDER BY "._CLMN_CHR_GRSTS_." DESC, "._CLMN_CHR_RSTS_." DESC");
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_gr.cache',$cacheDATA);
			break;
			case 'online':
				//$dbDATA = $this->GetResults(mconfig('rankings_results'),'TotalOnlineTime','DESC','AccountId,sum(OnlineDuration) as TotalOnlineTime',_TBL_LOGEX_,'AccountId',true);
				$dbDATA = $dB->query_fetch("SELECT TOP ".mconfig('rankings_results')." tb2."._CLMN_GAMEIDC_.", sum(tb1."._CLMN_LOGEX_OD_.") AS TotalOnlineDuration, tb3."._CLMN_CHR_CLASS_." FROM "._TBL_LOGEX_." AS tb1 INNER JOIN "._TBL_AC_." AS tb2 ON tb1."._CLMN_LOGEX_ACCID_." = tb2."._CLMN_AC_ID_." INNER JOIN "._TBL_CHR_." AS tb3 ON tb2."._CLMN_GAMEIDC_." = tb3."._CLMN_CHR_NAME_." GROUP BY tb1."._CLMN_LOGEX_ACCID_.", tb2."._CLMN_GAMEIDC_.", tb3."._CLMN_CHR_CLASS_." ORDER BY TotalOnlineDuration DESC");
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_online.cache',$cacheDATA);
			break;
			case 'votes':
			break;
			case 'guilds':
				$dbDATA = $this->GetResults(mconfig('rankings_results'),'G_Score','DESC','G_Name,G_Master,G_Score,G_Mark','Guild');
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_guilds.cache',$cacheDATA);
			break;
			case 'master':
				//$dbDATA = $this->GetResults(mconfig('rankings_results'), _CLMN_ML_LVL_,'DESC', 'CHAR_NAME,MASTER_LEVEL', _TBL_MASTERLVL_);
				$dbDATA = $dB->query_fetch("SELECT TOP ".mconfig('rankings_results')." t1."._CLMN_ML_NAME_.", t1."._CLMN_ML_LVL_.", t2."._CLMN_CHR_CLASS_.", t2."._CLMN_CHR_RSTS_." FROM "._TBL_MASTERLVL_." AS t1 INNER JOIN "._TBL_CHR_." AS t2 ON t1."._CLMN_ML_NAME_." = t2."._CLMN_CHR_NAME_." ORDER BY t1."._CLMN_ML_LVL_." DESC, t2."._CLMN_CHR_RSTS_." DESC");
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_master.cache',$cacheDATA);
			break;
			case 'pvplaststand':
				$dbDATA = $dB->query_fetch("SELECT TOP ".mconfig('rankings_results')." "._CLMN_CHR_NAME_.", "._CLMN_CHR_CLASS_.", "._CLMN_CHR_PVPLS_WIN_." FROM "._TBL_CHR_." ORDER BY "._CLMN_CHR_PVPLS_WIN_." DESC");
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_pvplaststand.cache',$cacheDATA);
			break;
			case 'gens':
				$dbDATA = $dB->query_fetch("SELECT TOP ".mconfig('rankings_results')." Name, GensContribution, GensType, GensRank, Class FROM Character WHERE GensKnight = 1 ORDER BY GensContribution DESC");
				$cacheDATA = BuildCacheData($dbDATA);
				UpdateCache('rankings_gens.cache',$cacheDATA);
			break;
			default:
			break;
		}
	}
	
	function GuildLogo($code,$xy=3) {
		// Convert HEX -> DEC
		$code = urlencode(bin2hex($code));
		$color[0] = '';
		$color[1] = '#000000';
		$color[2] = '#8c8a8d';
		$color[3] = '#ffffff';
		$color[4] = '#fe0000';
		$color[5] = '#ff8a00';
		$color[6] = '#ffff00';
		$color[7] = '#8cff01';
		$color[8] = '#00ff00';
		$color[9] = '#01ff8d';
		$color['a'] = '#00ffff';
		$color['b'] = '#008aff';
		$color['c'] = '#0000fe';
		$color['d'] = '#8c00ff';
		$color['e'] = '#ff00fe';
		$color['f'] = '#ff008c'; 
		// Default Position ZERO
		$i = 0; 
		$ii = 0;
		// Create Table
		$it = '<table class="rankings_guild_logo" style=\'width: '.(8*$xy).'px;height:'.(8*$xy).'px\' border=0 cellpadding=0 cellspacing=0><tr>';
		while ($i<64) {
			$place  = $code{$i};
			$i++;
			$ii++;
			$add = $color[$place];
			$it .= '<td class=\'guildlogo\' style=\'background-color: '.$add.';\' width=\''.$xy.'\' height=\''.$xy.'\'></td>';
			if ($ii==8) { 
				$it .=  '</tr>'; 
				if ($ii != 64) $it .= '<tr>';
				$ii = 0; 
			}
		}
		$it .= '</table>';
		return $it;
	}
	
	function rankingsMenu() {
		// Rankings to display
		$show_rankings = $_REQUEST['subpage'];
		loadModuleConfigs('rankings');

		$rankings_menu = array(
			array(lang('rankings_txt_1',true),'level',mconfig('rankings_enable_level')),
			array(lang('rankings_txt_2',true),'resets',mconfig('rankings_enable_resets')),
			array(lang('rankings_txt_3',true),'killers',mconfig('rankings_enable_pk')),
			array(lang('rankings_txt_4',true),'guilds',mconfig('rankings_enable_guilds')),
			array(lang('rankings_txt_5',true),'grandresets',mconfig('rankings_enable_gr')),
			array(lang('rankings_txt_6',true),'online',mconfig('rankings_enable_online')),
			array(lang('rankings_txt_7',true),'votes',mconfig('rankings_enable_votes')),
			array(lang('rankings_txt_8',true),'gens',mconfig('rankings_enable_gens')),
			array(lang('rankings_txt_22',true),'master',mconfig('rankings_enable_master')),
			array(lang('rankings_txt_24',true),'pvplaststand',mconfig('rankings_enable_pvplaststand')),
		);

		echo '<div class="rankings_menu">';
		echo '<span>'.lang('module_titles_txt_10',true).'</span>';
		foreach($rankings_menu as $rm_item) {
			if($rm_item[2]) {
				if($show_rankings == $rm_item[1]) {
					echo '<a href="'.__PATH_MODULES_RANKINGS__.$rm_item[1].'/" class="active">'.$rm_item[0].'</a>';
				} else {
					echo '<a href="'.__PATH_MODULES_RANKINGS__.$rm_item[1].'/">'.$rm_item[0].'</a>';
				}
			}
		}
		echo '</div>';
	}

}

?>